==> eslint-config-osedea-4.0.0.tgz: package/lib/rules/flowtype.js <==
// ----------------------------------------------------------------------------
// Flowtype
// https://github.com/gajus/eslint-plugin-flowtype
// ----------------------------------------------------------------------------

module.exports = {
    // Enforces a particular annotation style of complex types.
    'flowtype/array-style-complex-type': ['error', 'verbose'],

    // Enforces a particular array type annotation style of simple types.
    'flowtype/array-style-simple-type': ['error', 'verbose'],

    // Enforces a particular style for boolean type annotations.
    'flowtype/boolean-style': ['warn', 'boolean'],

    // Marks Flow type identifiers as defined.
    'flowtype/define-flow-type': 'error',

    // Enforces consistent use of trailing commas in Object and Tuple annotations.
    'flowtype/delimiter-dangle': ['warn', 'always-multiline'],

    // Enforces consistent spacing within generic type annotation parameters.
    'flowtype/generic-spacing': ['warn', 'never'],

    // Requires an empty line after the Flow annotation.
    'flowtype/newline-after-flow-annotation': ['error', 'always'],

    // Checks for duplicate properties in Object annotations
    'flowtype/no-dupe-keys': 'error',

    // Disallows use of the existential type (*)
    'flowtype/no-existential-type': 'warn',

    // Disallows `$FlowFixMe` comment suppressions.
    'flowtype/no-flow-fix-me-comments': 'warn',

    // Warns against "mixed" type annotations.
    'flowtype/no-mixed': 'warn',

    // Requires use of $ReadOnlyArray instead of just Array or array shorthand notation.
    'flowtype/no-mutable-array': 'off', // TODO

    // Disallows use of primitive constructors as types, such as Boolean, Number and String.
    'flowtype/no-primitive-constructor-types': 'error',

    // Disallows Flow type imports, aliases, and annotations in files missing a valid Flow file declaration (or a @noflow annotation).
    'flowtype/no-types-missing-file-annotation': 'warn', // TODO

    // An extension of ESLint's no-unused-expressions. This rule ignores type cast expressions, but otherwise behaves the same as ESLint's no-unused-expressions.
    'flowtype/no-unused-expressions': 'error',

    // Warns against weak type annotations any, Object and Function.
    'flowtype/no-weak-types': 'warn', // TODO
    // ['warn', {
    //     any: false,
    //     Object: false,
    //     Function: true,
    // }]

    // Enforces consistent separators between properties in Flow object types.
    'flowtype/object-type-delimiter': ['warn', 'comma'],

    // Requires to make a type alias for all union and intersection types.
    'flowtype/require-compound-type-alias': ['warn', 'always'],

    // Enforces exact object types.
    'flowtype/require-exact-type': 'off', // TODO

    // Requires that all function parameters have type annotations.
    'flowtype/require-parameter-type': 'warn', // TODO

    // Requires that functions have return type annotation.
    'flowtype/require-return-type': 'off', // TODO

    // Requires all type declarations to be at the top of the file, after any import declarations.
    'flowtype/require-types-at-top': 'off', // TODO

    // Makes sure that files have a valid @flow annotation.
    'flowtype/require-valid-file-annotation': ['warn', 'always', { annotationStyle: 'none' }],

    // Requires that all variable declarators have type annotation
    'flowtype/require-variable-type': 'off', // TODO

    // Enforces consistent use of semicolons after type aliases.
    'flowtype/semi': ['warn', 'always'],

    // Enforces sorting of Object annotations
    'flowtype/sort-keys': 'off', // TODO

    // Enforces consistent spacing after the type annotation colon.
    'flowtype/space-after-type-colon': ['warn', 'always'],

    // Enforces consistent spacing before the opening < of generic type annotation parameters.
    'flowtype/space-before-generic-bracket': ['warn', 'never'],

    // Enforces consistent spacing before the type annotation colon.
    'flowtype/space-before-type-colon': ['warn', 'never'],

    // Enforce object types, that are spread to be exact type explicitly.
    'flowtype/spread-exact-type': 'warn',

    // Enforces a consistent naming pattern for type aliases.
    'flowtype/type-id-match': 'off', // TODO

    // Enforces a particular style for type imports
    'flowtype/type-import-style': 'off', // TODO

    // Enforces consistent spacing around union and intersection type separators (| and &).
    'flowtype/union-intersection-spacing': ['warn', 'always'],

    // Marks Flow type alias declarations as used.
    'flowtype/use-flow-type': 'error',
};

==> eslint-config-osedea-6.2.0.tgz: package/lib/rules/flowtype.js <==
// ----------------------------------------------------------------------------
// Flowtype
// https://github.com/gajus/eslint-plugin-flowtype
// ----------------------------------------------------------------------------

const rules = {
    // Enforces a particular annotation style of complex types.
    'flowtype/array-style-complex-type': ['error', 'verbose'],

    // Enforces a particular array type annotation style of simple types.
    'flowtype/array-style-simple-type': ['error', 'verbose'],

    // Enforces the consistent use of parentheses in arrow functions.
    'flowtype/arrow-parens': ['error', 'always'],

    // Enforces a particular style for boolean type annotations.
    'flowtype/boolean-style': ['warn', 'boolean'],

    // Marks Flow type identifiers as defined.
    'flowtype/define-flow-type': 'error',

    // Enforces consistent use of trailing commas in Object and Tuple annotations.
    'flowtype/delimiter-dangle': ['warn', 'always-multiline'],

    // Enforces consistent spacing within generic type annotation parameters.
    'flowtype/generic-spacing': ['warn', 'never'],

    // Requires an empty line after the Flow annotation.
    'flowtype/newline-after-flow-annotation': ['error', 'always'],

    // Checks for duplicate properties in Object annotations
    'flowtype/no-dupe-keys': 'error',

    // Disallows use of the existential type (*)
    'flowtype/no-existential-type': 'warn',

    // Disallows `$FlowFixMe` comment suppressions.
    'flowtype/no-flow-fix-me-comments': 'warn',

    // Warns against "mixed" type annotations.
    'flowtype/no-mixed': 'warn',

    // Requires use of $ReadOnlyArray instead of just Array or array shorthand notation.
    'flowtype/no-mutable-array': 'off', // TODO

    // Disallows use of primitive constructors as types, such as Boolean, Number and String.
    'flowtype/no-primitive-constructor-types': 'error',

    // Disallows Flow type imports, aliases, and annotations in files missing a valid Flow file declaration (or a @noflow annotation).
    'flowtype/no-types-missing-file-annotation': 'warn', // TODO

    // An extension of ESLint's no-unused-expressions. This rule ignores type cast expressions, but otherwise behaves the same as ESLint's no-unused-expressions.
    'flowtype/no-unused-expressions': 'error',

    // Warns against weak type annotations any, Object and Function.
    'flowtype/no-weak-types': 'warn', // TODO
    // ['warn', {
    //     any: false,
    //     Object: false,
    //     Function: true,
    // }]

    // Enforces consistent separators between properties in Flow object types.
    'flowtype/object-type-delimiter': ['warn', 'comma'],

    // Requires to make a type alias for all union and intersection types.
    'flowtype/require-compound-type-alias': ['warn', 'always'],

    // Enforces exact object types.
    'flowtype/require-exact-type': 'off', // TODO

    // This rule validates Flow object indexer name.
    'flowtype/require-indexer-name': 'off', // TODO

    // This rule enforces explicit inexact object types.
    'flowtype/require-inexact-type': 'off', // TODO

    // Requires that all function parameters have type annotations.
    'flowtype/require-parameter-type': 'warn', // TODO

    // This rule validates that React props are marked as $ReadOnly.
    // React props are immutable and modifying them could lead to unexpected results.
    // Marking prop shapes as $ReadOnly avoids these issues.
    'flowtype/require-readonly-react-props': 'error',

    // Requires that functions have return type annotation.
    'flowtype/require-return-type': 'off', // TODO

    // Requires all type declarations to be at the top of the file, after any import declarations.
    'flowtype/require-types-at-top': 'off', // TODO

    // Makes sure that files have a valid @flow annotation.
    'flowtype/require-valid-file-annotation': [
        'warn',
        'always',
        { annotationStyle: 'none', strict: true },
    ],

    // Requires that all variable declarators have type annotation
    'flowtype/require-variable-type': 'off', // TODO

    // Enforces consistent use of semicolons after type aliases.
    'flowtype/semi': ['warn', 'always'],

    // Enforces sorting of Object annotations
    'flowtype/sort-keys': 'off', // TODO

    // Enforces consistent spacing after the type annotation colon.
    'flowtype/space-after-type-colon': ['warn', 'always'],

    // Enforces consistent spacing before the opening < of generic type annotation parameters.
    'flowtype/space-before-generic-bracket': ['warn', 'never'],

    // Enforces consistent spacing before the type annotation colon.
    'flowtype/space-before-type-colon': ['warn', 'never'],

    // Enforce object types, that are spread to be exact type explicitly.
    'flowtype/spread-exact-type': 'warn',

    // Enforces a consistent naming pattern for type aliases.
    'flowtype/type-id-match': 'off', // TODO

    // Enforces a particular style for type imports
    'flowtype/type-import-style': 'off', // TODO

    // Enforces consistent spacing around union and intersection type separators (| and &).
    'flowtype/union-intersection-spacing': ['warn', 'always'],

    // Marks Flow type alias declarations as used.
    'flowtype/use-flow-type': 'error',
};

module.exports = {
    plugins: ['flowtype'],

    rules,
};
